Learn R Programming

dtwclust (version 0.1.0)

dtwclust-class: Class definition for dtwclust

Description

Formal S4 class to know how to handle data for plotting.

Arguments

Details

It contains the following specific slots:

  • type: A string indicating one of the supported clustering types ofdtwclust.
  • distance: A string indicating one of the supported distances ofdtwclust.
  • centroid: A string indicating one of the supported centroids ofdtwclust.

Additionally, the class inherits from kccasimple-class, so all related slots and methods are also supported.