dtwclustFamily-class: Class definition for dtwclustFamily
Description
Formal S4 class with a family of functions used in dtwclust.Details
The custom implementations also handle parallelization.
Since the distance function makes use of proxy, it also supports any extra dist
parameters in ....
The prototype includes the cluster function for partitional methods, as well as a
pass-through preproc function.