dtwclusttype: A string indicating one of the supported clustering types ofdtwclust.distance: A string indicating one of the supported distances ofdtwclust.centroid: A string indicating one of the supported centroids ofdtwclust.Additionally, the class inherits from kccasimple-class, so all related slots and
methods are also supported.